// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

// Codes that start with // are COMMENTS (notes to yourself)

/*  USE COLORS TO HELP YOU! Comments are GREEN,STATA system commands are BLUE,
    Variables and file names are BLACK, File references and Labels in RED
    are case-sensitive and space-sensitive, no color for "wrong" though

    STATA commands must be in lower-case
	STATA variables are case-sensitive 
	STATA is line-sensitive, so to continue a line use ///   */
   
/* STATA commands do not have a line terminator
   commas are used to distinguish options
   Data transformations (e.g., making new variables) can happen in open code
     because only one dataset can be active at a time (through STATA 15) */

// To execute select code, highlight it and hit keyboard short-cut control+D	

********************************************************************************
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION       *******
********************************************************************************

// Paste in the folder address where "GSS_Example.xlsx" is saved between " "
   global filesave "C:\Dropbox\20FA_PSQF6242\PSQF6242_Example1"

// We can then refer to the syntax variable "filesave" by putting $ in front

// IMPORT GSS_Example.xlsx data using filesave reference and exact file name
// To change all variable names to lowercase, remove "case(preserve")
   clear // Clear before means close any open data
   import excel "$filesave\GSS_Example.xlsx", case(preserve) firstrow clear 
// Clear after means re-import if it already exists (need to start over)
					   
// Create formats: set of value labels for categorical variables;					   
   label define Fmarital 1 "1.Married" 2 "2.Widowed" 3 "3.Divorced" ///
                            4 "4.Separated" 5 "5.Never Married"
   
// Label variables and apply value formats for variables used below
// label variable name      "name: Descriptive Variable Label"   
   label variable marital   "marital: 5-Category Marital Status"
   label variable educ      "educ: Years of Education"
   label variable income    "income: Annual Income in 1000s"
// Apply value labels created above: name Format
   label values marital Fmarital
// Now datset is ready to use
   
********************************************************************************
*******              BEGIN EXAMPLE 1 UNIVARIATE STATISTICS               *******
********************************************************************************				   
		
// Save results to separate text file (replace if exists already)
   log using $filesave\Example1_STATA_Output.log, replace		
		
// display is like TITLE in SAS: prints text in output

// tabulate prints frequency tables, missing includes missing values too  
   display "Frequency Table for Categorical Variable marital"
   tabulate marital, missing
   
// histogram provides a frequency plot (in frequency or percent)
// on x-axis, go from 1 to 5 using value labels alternating vertical placement
   display "Frequency Plot for Categorical Variable marital"
   histogram marital, discrete percent xla(1/5, valuelabel alternate)
   
// here is how you save a graph (replace = write over it)
   graph export "$filesave\STATA Marital Frequency Plot.png", replace

// summarize prints sample descriptive statistics for quantitative variables 
// can use format to control how many digits after decimal show in summarize
// detail asks for more than just N Mean SD Min Max
   display "Univariate Statistics for Quantitative Variable income"
   format income %8.3f
   summarize income, format detail 
      
// histogram for quantitative variable
   display "Histogram for Quantitative Variable income"
   histogram income, percent width(5) start(0) 

   
********************************************************************************
*******             BEGIN EXAMPLE 1 UNIVARIATE TESTS OF MEANS            *******
********************************************************************************

// TTEST to compare sample mean to H0=expected at alpha=.05
   display "Is the mean of years of education different than 12?"
   ttest educ==12, level(95)
   
// CI requests confidence interval for variance as separate command
   display "Confidence interval for variance of education"
   ci variances educ, level(95)
   
// To test the proprotion of high school non-graduates or graduates, 
// we will need to make 2 new variables using conditional logic
   gen lessHS=.  // First create 2 new empty variables
   gen gradHS=.
// Second assign their values using conditional logic;
   replace lessHS=1 if educ>0 & educ<12 
   replace gradHS=0 if educ>0 & educ<12 
   replace lessHS=0 if educ>=12  
   replace gradHS=1 if educ>=12  
   
// PRTEST: compare sample proportion to variable=expected at alpha=.05
// STATA always tests proportion of 1 values against H0

   display "Is the proportion of HS non-graduates different than .10?"
   prtest lessHS==.10, level(95)
      
   display "Is the proportion of HS graduates different than .90?"
   prtest gradHS==.90, level(95)
   
////////////////////////////////////////////////////////////////////////////////
// Close log
   log close  




  
	  
	 



